dipa makes it easy to efficiently delta encode large Rust data structures.
Repository
The source code is available at [https://github.com/chinedufn/dipa]
Documentation
The Dipa Book introduces you to dipa and teaches you how to use it.
It is available online at [https://chinedufn.github.io/dipa/]
You can also view the book offline:
# Do this once while online
git clone git@github.com:chinedufn/dipa.git && cd dipa
cargo install mdbook
# This works offline
./bin/serve-book.shMacros
- Used for integer and float types excluding
u8andi8since those two do not use Option wrappers. - Used for u8 and i8 since their diffs are not wrapped in Option. TODO: Rename to single_byte_impl or something, since we use this for bools
Structs
- The type returned by [Diffable.create_delta_towards].
Traits
- Allows a type to be diffed with another type.
- Modifies a type using n a patch.